@@ -4,7 +4,8 @@ __all__ = [
     'NotebookExecutorBase',
     'InMemoryQueryExecutorBase',
     'FeatureComputeBase',
-    'FeaturesetExtractorBase'
+    'FeaturesetExtractorBase',
+    'MetricsBase'
 ]
 
 from .fileops import *
@@ -12,3 +13,4 @@ from .filebased_query_executor import *
 from .inmemory_query_executor import *
 from .notebook_executor import * 
 from .feature_compute import *
+from .metrics import *
