@@ -135,6 +135,8 @@ class InMemoryQueryExecutorBase(Compute):
         # Compute the targets
         targets = ['all'] #default
         for s in specs:
+            if not s.get('enable', True):
+                continue
             categories = s.get('categories', [])
             for c in categories:
                 if c not in targets:
@@ -194,13 +196,7 @@ class InMemoryQueryExecutorBase(Compute):
         }
 
         # Generate column information...
-        columns = {}
-        for col in df.columns:
-            columns[col] = {
-                'touch': self.name,
-                'description': self.get_column_description(name, col),
-                'datatype': df.get_generic_dtype(col),
-            }
+        columns = self.get_column_metadata(name, df)
 
         ## => Gather the update parameters
         updated_detail = {
@@ -239,9 +235,12 @@ class InMemoryQueryExecutorBase(Compute):
                 {
                     'start_date': start_date.isoformat(),
                     'end_date': end_date.isoformat(),
+                    'start_date_minus7': (start_date + relativedelta.relativedelta(days=-7)).isoformat(),
                     'start_date_minus1': (start_date + relativedelta.relativedelta(days=-1)).isoformat(),
+                    'start_date_minus6_months': (start_date + relativedelta.relativedelta(months=-6)).isoformat(),
                     'end_date_plus1': (end_date + relativedelta.relativedelta(days=1)).isoformat(),
                     'end_date_minus1': (end_date + relativedelta.relativedelta(days=-1)).isoformat(),
+                    'end_date_minus7': (end_date + relativedelta.relativedelta(days=-7)).isoformat(),
                     'end_date_minus6_months': (end_date + relativedelta.relativedelta(months=-6)).isoformat(),
                 }
             ]
@@ -255,8 +254,8 @@ class InMemoryQueryExecutorBase(Compute):
 
             # Sanity check
             diff = end_date - start_date
-            if diff.days > 90:
-                raise Exception("Date range should be < 90 days")
+            if diff.days > 100:
+                raise Exception("Date range should be < 100 days")
 
             # Generate one for each day
             paramsets = []
@@ -265,9 +264,13 @@ class InMemoryQueryExecutorBase(Compute):
                 paramsets.append({
                     'start_date': curr_date.isoformat(),
                     'end_date': (curr_date + relativedelta.relativedelta(days=window)).isoformat(),
+                    'start_date_minus7': (curr_date + relativedelta.relativedelta(days=-7)).isoformat(),
                     'start_date_minus1': (curr_date + relativedelta.relativedelta(days=-1)).isoformat(),
+                    'start_date_plus1': (curr_date + relativedelta.relativedelta(days=1)).isoformat(),
+                    'end_date_minus1': (curr_date + relativedelta.relativedelta(days=-1)).isoformat(),
                     'end_date_plus1': (curr_date + relativedelta.relativedelta(days=1)).isoformat(),
-                    'end_date_minus6_months': (end_date + relativedelta.relativedelta(months=-6)).isoformat(),
+                    'end_date_minus7': (curr_date + relativedelta.relativedelta(days=-7)).isoformat(),
+                    'end_date_minus6_months': (curr_date + relativedelta.relativedelta(months=-6)).isoformat(),
                 })
                 curr_date += relativedelta.relativedelta(days=1)
 
@@ -285,14 +288,9 @@ class InMemoryQueryExecutorBase(Compute):
           * name: Name of the specification
           * sql: SQL template
           * categories: String or a list of strings indicating specification groups
-             to which the spec belongs
-          * segment: How to split the dataframe resulting from query execution. Could
-             be none ('complete' as the default name), string (column name) or
-             a callback that generates a { name: df } map
-          * paramsets_duration: each instance for one 'day' or a window
-             of days (defined below)
-          * paramsets_window: each instance translates into date range
-             for each instance of parameters. The
+          * segment: How to split the dataframe resulting from query execution. Could be none ('complete' as the default name), string (column name) or a callback that generates a { name: df } map
+          * paramsets_duration: each instance for one 'day' or a window of days (defined below)
+          * paramsets_window: each instance translates into date range for each instance of parameters.
 
         Examples::
 
@@ -476,7 +474,7 @@ class InMemoryQueryExecutorBase(Compute):
                     elif callable(segmentcol):
                         # Custom split of the dataframe...
                         filemap = segmentcol(self, spec, params, df)
-                        msg += "Segments: {len(filemap)}}\n"
+                        msg += f"Segments: {len(filemap)}\n"
                     else:
                         raise Exception(f"Unhandled segment definition: {segmentcol}")
 
