@@ -28,6 +28,21 @@ widgetdir = os.path.join(templatedir, 'widgets')
 
 __all__ = ['Node', 'Transform', 'Model', 'Skin', 'Integration']
 
+def flatten(c):
+    if isinstance(c, (int, float, str)):
+        return c
+
+    try:
+        if isinstance(c, (datetime, date)):
+            c = c.isoformat()
+        elif isinstance(c, (dict, list)):
+            c = json.dumps(c)
+        else:
+            c = str(c)
+    except:
+        c = str(c)
+    return c[:30]
+
 class NodeMeta(abc.ABCMeta):
     """
     Meta class for all elements with schemas. This allows for
@@ -1064,7 +1079,7 @@ class Node(metaclass=NodeMeta):
         ----------
         None
 
-        .. deprecated:: 
+        .. deprecated::
            Use configure/other functions to complete the initialization..
 
         """
@@ -1427,7 +1442,7 @@ class Transform(Node):
     def get_column_params(self, name, df):
         """
         Generate columns metadata to be associated with
-        this dataframe in the state.
+        this dataframe in the state. In params form.
 
         Args:
             name (str): name of the dataframe being processed
@@ -1437,20 +1452,40 @@ class Transform(Node):
             List of dicts. Each dict has 'type' (columns) and
             columns metadata (a dict)
         """
-        columns = {}
-        for c in list(df.columns):
-            columns[c] = {
-                'touch': self.name, # Who is introducing this column
-                'datatype': df.get_generic_dtype(c), # What is its type
-                'description': self.get_column_description(name, c),
-                'security': self.get_column_security(name, c),
-            }
+        columns = self.get_column_metadata(name, df)
 
         return [{
             'type': 'compute',
             'columns': columns
         }]
 
+    def get_column_metadata(self, name, df):
+        """
+        Generate columns metadata to be associated with
+        this dataframe in the state.
+
+        Args:
+            name (str): name of the dataframe being processed
+            df (DataFrame): Dataframe to be documented
+
+        Returns:
+            Dict with columns metadata
+        """
+        columns = {}
+        for c in list(df.columns):
+            sample = list(df[c].sample(min(3, df.shape[0])))
+            sample = [flatten(c) for c in sample]
+            columns[c] = {
+                'touch': self.name, # Who is introducing this column
+                'datatype': df.get_generic_dtype(c), # What is its type
+                'description': self.get_column_description(name, c),
+                'version': self.get_column_version(name, c),
+                'security': self.get_column_security(name, c),
+                'sample': sample
+            }
+
+        return columns
+
     #####################################################
     #=> Column output
     #####################################################
@@ -1606,6 +1641,25 @@ class Transform(Node):
 
         return {}
 
+    def get_column_version(self, frame, column, outputs=None):
+        """
+        Look through the output definition to extract version  attributes
+
+        Args:
+            frame (object): name of the dataframe being processed
+            column (object): Name of the column whose version attributes are required
+
+        Returns:
+            string (version)
+
+        """
+        # There may be multiple matches
+        matched_details = self.lookup_column_output(frame, column, outputs)
+        if len(matched_details) > 0:
+            return matched_details[0].get('version', "v1")
+
+        return "v1" # default
+
 
     def validate_results(self, what, state):
         """
