@@ -532,7 +532,7 @@ class RunBase(object):
 
                 # Component looks like this...
                 {
-                    'filename': 'hopscotch/PLP/output/PLPTargetOnly/plptarget-20191002-165551/product_persona.csv',
+                    'filename': 'acme/PLP/output/PLPTarget/plptarget-20191002-165551/product_persona.csv',
                     'modified_time': 'Wed Oct 2 16:58:25 2019',
                     'sha256sum': 'e9731bdc22f545da71304e77d50da31ccb263458317a2c1b7b73177092ad5d73',
                     'columns': 2,
