@@ -32,85 +32,18 @@ class DataSource(object):
         Example: "Daily events for Alpha Sensor"
         """
 
+        self.version = params.get('version','v1')
+        """
+        str: Version
+        Example: "v1"
+        """
+
         self.resolve = kwargs.get('resolve',
                                   params.get('resolve',{}))
         """
         Parameters to resolve paths
         """
 
-    def set_resolve(self, resolve):
-        """
-        Allow the user to specify a resolving dict
-        """
-        assert isinstance(resolve, dict)
-        assert len(resolve) > 0
-        self.resolve.update(resolve)
-
-    def __str__(self):
-        return "[{}] {}".format(self._type, self.name)
-
-
-class DatabaseTable(DataSource):
-
-    def __init__(self, params, *args, **kwargs):
-        super().__init__(params, *args, **kwargs)
-        self._type = "DBTable"
-
-class Dataset(DataSource):
-    """
-    Class for specifying a dataset. This is typically
-    an input to the transforms.
-
-    Usage::
-
-        # A dataset that has one directory for each day. Within that
-        # there are atleast two sub-datasets
-        Dataset(params={
-            "name": 'athena-availability',
-            "type": "file",
-            "paths": [
-                {
-                    "name": "test",
-                    "nature": "local",
-                    "path": "%(data_root)s/shared/datasets/athena/v2/availability",
-
-                },
-                {
-                    "name": "local",
-                    "nature": "local",
-                    "path": "%(enrich_data_dir)s/acme/Marketing/shared/datasets/athena/v2/availability",
-                },
-                {
-                    "name": "s3",
-                    "nature": "s3",
-                    "path": "%(backup_root)s/%(node)s/data/acme/Marketing/shared/datasets/athena/v2/availability",
-                },
-            ],
-            "match": {
-                "generate": "generate_datetime_daily",
-                "compare": "compare_datetime_pattern_match_range",
-                "pattern": "%Y-%m-%d",
-            },
-            "subsets": [
-                {
-                    "name": "CatalogScore",
-                    "pattern": ".*catalogscore.csv$",
-                    "description": "Score of all products in the catalog"
-                },
-                {
-                    "name": "ProductWeight",
-                    "pattern": ".*productweight.csv$",
-                    "description": "Assortment weight for each product"
-                }
-            ]
-        })
-
-    """
-
-    def __init__(self, params, *args, **kwargs):
-
-        super().__init__(params, *args, **kwargs)
-
         # Backward compatability
         if 'paths' not in params:
             params['paths'] = []
@@ -175,79 +108,13 @@ class Dataset(DataSource):
            ]
         """
 
-        self.match = params.get('match',{})
+    def set_resolve(self, resolve):
         """
-        dict: Generating and matching rules
-
-        Example::
-
-            {
-                "generate": "generate_datetime_daily",
-                "match": "match_datetime_pattern_range",
-                "pattern": "plpevents-%Y%m%d-%H%M%S",
-            }
+        Allow the user to specify a resolving dict
         """
-
-    def sample(self, filename, safe=True, fd=None):
-        """
-        Sample a file belonging to this dataset.Subclass and
-        overload this function if the data is sensitive.
-
-        Args:
-            filename (str): A file that belongs to this dataset
-            safe (bool): Whether file is trusted
-            fd (object): File descriptor for s3/gcs/other non-filesystems
-
-        """
-
-        if fd is None:
-            # Text formats..
-            if filename.split(".")[-1].lower() in ['csv', 'tsv']:
-                fd = open(filename)
-            else:
-                fd = open(filename, 'rb')
-
-        # Read the file
-        if filename.lower().endswith('.csv'):
-            df = pd.read_csv(fd, nrows=10)
-        elif filename.lower().endswith('.csv.gz'):
-            df = pd.read_csv(fd, nrows=10, compression='gzip', error_bad_lines=False)
-        elif filename.lower().endswith('.tsv.gz'):
-            df = pd.read_csv(fd, nrows=10, sep='\t', compression='gzip',
-                             error_bad_lines=False)
-        elif filename.lower().endswith('.tsv'):
-            df = pd.read_csv(fd, nrows=10, sep='\t')
-        elif filename.lower().endswith('.pq') or filename.lower().endswith(".pq.sample"):
-            df = pd.read_parquet(fd)
-            df = df.head(10)
-        else:
-            raise Exception(f"Unknown file format: {filename}")
-
-        return df
-
-    @property
-    def local(self):
-        """
-        Read the path with the name 'local'. Available for
-        backward compatability
-        """
-        return self.get_path('local')
-
-    @property
-    def test(self):
-        """
-        Read the path with the name 'test'. Available for
-        backward compatability
-        """
-        return self.get_path('test')
-
-    @property
-    def backup(self):
-        """
-        Read the path with the name 'backup'. Available for
-        backward compatability
-        """
-        return self.get_path('backup')
+        assert isinstance(resolve, dict)
+        assert len(resolve) > 0
+        self.resolve.update(resolve)
 
     def get_paths(self):
         """
@@ -368,6 +235,166 @@ class Dataset(DataSource):
     def get_path(self, name, full=False, resolve=None):
         return self.get_path_by_name(name, full, resolve)
 
+    def validate(self, params):
+        """
+        """
+        if not isinstance(params, dict):
+            raise Exception("Invalid parameters for dataset")
+
+        for col in ['name', 'paths']:
+            if col not in params:
+                raise Exception("Data specification should have {}".format(col))
+
+        if (not isinstance(params['paths'], list)):
+            raise Exception("Paths should be a list of dictionaries")
+
+        for elem in params['paths']:
+            if not isinstance(elem, dict) or len(elem) == 0:
+                raise Exception("paths element should be non-empty dict")
+            if (('nature' not in elem) or (elem['nature'] not in self.valid_natures)):
+                raise Exception(f"paths element have nature {'|'.join(self.valid_natures)}")
+            if 'path' not in elem:
+                raise Exception("paths element should have a 'path'")
+
+
+    def __str__(self):
+        return "[{}] {}".format(self._type, self.name)
+
+
+class Dataset(DataSource):
+    """
+    Class for specifying a dataset. This is typically
+    an input to the transforms.
+
+    Usage::
+
+        # A dataset that has one directory for each day. Within that
+        # there are atleast two sub-datasets
+        Dataset(params={
+            "name": 'athena-availability',
+            "type": "file",
+            "paths": [
+                {
+                    "name": "test",
+                    "nature": "local",
+                    "path": "%(data_root)s/shared/datasets/athena/v2/availability",
+
+                },
+                {
+                    "name": "local",
+                    "nature": "local",
+                    "path": "%(enrich_data_dir)s/acme/Marketing/shared/datasets/athena/v2/availability",
+                },
+                {
+                    "name": "s3",
+                    "nature": "s3",
+                    "path": "%(backup_root)s/%(node)s/data/acme/Marketing/shared/datasets/athena/v2/availability",
+                },
+            ],
+            "match": {
+                "generate": "generate_datetime_daily",
+                "compare": "compare_datetime_pattern_match_range",
+                "pattern": "%Y-%m-%d",
+            },
+            "subsets": [
+                {
+                    "name": "CatalogScore",
+                    "pattern": ".*catalogscore.csv$",
+                    "description": "Score of all products in the catalog"
+                },
+                {
+                    "name": "ProductWeight",
+                    "pattern": ".*productweight.csv$",
+                    "description": "Assortment weight for each product"
+                }
+            ]
+        })
+
+    """
+
+    def __init__(self, params, *args, **kwargs):
+
+        super().__init__(params, *args, **kwargs)
+
+        self.match = params.get('match',{})
+        """
+        dict: Generating and matching rules
+
+        Example::
+
+            {
+                "generate": "generate_datetime_daily",
+                "match": "match_datetime_pattern_range",
+                "pattern": "plpevents-%Y%m%d-%H%M%S",
+            }
+        """
+
+    def sample(self, filename, safe=True, fd=None, nrows=10):
+        """
+        Sample a file belonging to this dataset.Subclass and
+        overload this function if the data is sensitive.
+
+        Args:
+            filename (str): A file that belongs to this dataset
+            safe (bool): Whether file is trusted
+            fd (object): File descriptor for s3/gcs/other non-filesystems
+            nrows (int): Number of rows to sample
+        """
+
+        if fd is None:
+            # Text formats..
+            if filename.split(".")[-1].lower() in ['csv', 'tsv']:
+                fd = open(filename)
+            else:
+                fd = open(filename, 'rb')
+
+        # Read the file
+        if filename.lower().endswith('.csv'):
+            df = pd.read_csv(fd, nrows=nrows)
+        elif filename.lower().endswith('.csv.gz'):
+            df = pd.read_csv(fd, nrows=nrows, compression='gzip', error_bad_lines=False)
+        elif filename.lower().endswith('.tsv.gz'):
+            df = pd.read_csv(fd, nrows=nrows, sep='\t', compression='gzip',
+                             error_bad_lines=False)
+        elif filename.lower().endswith('.tsv'):
+            df = pd.read_csv(fd, nrows=nrows, sep='\t')
+        elif filename.lower().endswith('.pq') or filename.lower().endswith(".pq.sample"):
+            df = pd.read_parquet(fd)
+            if nrows is not None:
+                df = df.head(nrows)
+        else:
+            raise Exception(f"Unknown file format: {filename}")
+
+        return df
+
+    @property
+    def local(self):
+        """
+        Read the path with the name 'local'. Available for
+        backward compatability
+        """
+        return self.get_path('local')
+
+    @property
+    def test(self):
+        """
+        Read the path with the name 'test'. Available for
+        backward compatability
+        """
+        return self.get_path('test')
+
+    @property
+    def backup(self):
+        """
+        Read the path with the name 'backup'. Available for
+        backward compatability
+        """
+        return self.get_path('backup')
+
+    @property
+    def valid_natures(self):
+        return ['local', 'remote', 's3', 'gcs']
+
     def validate(self, params):
         """
         Validate dataset arguments. It should be a dictionary
@@ -382,26 +409,12 @@ class Dataset(DataSource):
           * match: dictionary with generate function (name or lambda), are function (name or lambda), and pattern (string).
 
         """
-        if not isinstance(params, dict):
-            raise Exception("Invalid parameters for dataset")
 
-        for col in ['name', 'match', 'paths']:
-            if col not in params:
-                raise Exception("Data specification should have {}".format(col))
+        super().validate(params)
 
-        if (not isinstance(params['paths'], list)):
-            raise Exception("Paths should be a list of dictionaries")
-
-        for elem in params['paths']:
-            if not isinstance(elem, dict) or len(elem) == 0:
-                raise Exception("paths element should be non-empty dict")
-            if (('nature' not in elem) or (elem['nature'] not in ['local', 'remote', 's3', 'gcs'])):
-                raise Exception("paths element have nature (local|remote|s3|gcs)")
-            if 'path' not in elem:
-                raise Exception("paths element should have a 'path'")
-
-        if not isinstance(params['match'], dict):
-            raise Exception("Match should be a dictionary")
+        # If match is specified, then do something...
+        if (('match' not in params) or (not isinstance(params['match'], dict))):
+            raise Exception("Match should be a valid dictionary")
 
         if 'pattern' not in params['match']:
             raise Exception("Matching requirement match.pattern missing")
@@ -421,8 +434,6 @@ class Dataset(DataSource):
             (not callable(compare))):
             raise Exception("Matching requirement {} missing/invalid".format(compare))
 
-
-
     def generate(self, start, end=None):
         """
         Given a start and an end, generate the datetime
@@ -645,6 +656,7 @@ class Dataset(DataSource):
                   end_date,
                   filename,
                   readfunc,
+                  errors=True,
                   name="default",
                   params={},
                   resolve={}):
@@ -663,7 +675,13 @@ class Dataset(DataSource):
         _dfs = []
         for dt in dates:
             fullpath = os.path.join(path, dt['name'], filename)
-            df = readfunc(fullpath, params)
+            try: 
+                df = readfunc(fullpath, params, date=dt['name'])
+                if ((df is None) or (len(df) == 0)):
+                    continue
+            except:
+                if errors:
+                    raise
             _dfs.append(df)
 
         df = pd.concat(_dfs, ignore_index=True)
@@ -671,6 +689,17 @@ class Dataset(DataSource):
 
         return df
 
+class DatabaseTable(DataSource):
+
+    def __init__(self, params, *args, **kwargs):
+        super().__init__(params, *args, **kwargs)
+        self._type = "DBTable"
+
+
+    @property
+    def valid_natures(self):
+        return ['db']
+
 class Arg():
     """
     Dataset command argument
