@@ -6,7 +6,7 @@ def log_setup(logfile=None):
 
 
     if logfile is not None:
-        handler = logging.handlers.RotatingFileHandler('log.json',
+        handler = logging.handlers.RotatingFileHandler(logfile,
                                                        maxBytes=10*1000*1000,
                                                        encoding='utf-8')
     else:
